{
  using namespace RooFit;
  RooRealVar x("x","Bad Gaussian",-10.,10.);
  RooRealVar mean("mean","mean of Gaussian",0.,-10.,10.) ;
  RooRealVar sigma1("sigma1","width of narrow Gaussian",1.2,0.1,10.) ;
  RooRealVar sigma2("sigma2","width of wide Gaussian",3.4,2.,10.) ;
  RooGaussian gauss1("gauss1","Narrow Gaussian",x,mean,sigma1);
  RooGaussian gauss2("gauss2","Wide Gaussian",x,mean,sigma2);
  RooRealVar N1("N1","events in narrow Gaussian",6000.,0.,1000000.);
  RooRealVar N2("N2","events in wide Gaussian",3000.,0.,1000000.);
  RooAddPdf twogauss("twogauss","Two Gaussians pdf",
                    RooArgList(gauss1,gauss2),RooArgList(N1,N2));


  TCanvas cfun("cfun","Plot of a function",400,400);
  RooPlot* xframe = x.frame();
  twogauss.plotOn(xframe);
  twogauss.plotOn(xframe,Components("gauss2"),LineStyle(kDashed));
  twogauss.plotOn(xframe,Components("gauss1"),LineColor(kRed));
  xframe.Draw();
  
  TCanvas chist("chist","Plot of a dataset",400,400);
  RooDataSet* mydata = twogauss.generate(x,10000);
  RooPlot* xframe2 = x.frame();
  mydata->plotOn(xframe2);
  xframe2.Draw();

  TCanvas cfit("fit","Plot of a fitted dataset",400,400);
  RooFitResult* fitres = twogauss.fitTo(*mydata,Save());
  twogauss.plotOn(xframe2);
  twogauss.plotOn(xframe2,Components("gauss2"),LineStyle(kDashed));
  xframe2.Draw();
  fitres->Print();
  fitres->correlationMatrix()->Print();
  
  TH1F* myh = x.createHistogram("myh","Entries");
  TH1* myh2 = mydata->fillHistogram(myh,x);
  TTree* myTree = mydata->tree();
  TFile *myHisto = TFile::Open("myTwoGaussian.root","UPDATE");
  myh2->Write();
  myTree->Write();
  myHisto->Close();
}
